@@ -1,5 +1,6 @@
 #include <config.h>
 
+#include <gtkmm/messagedialog.h>
 #include <glib/gi18n.h>
 #include <glibtop/procopenfiles.h>
 
@@ -13,7 +14,7 @@
 #include <sstream>
 #include <iterator>
 
-// #include <pcrecpp.h>
+#include "regex.h"
 
 #include "procman.h"
 #include "lsof.h"
@@ -26,14 +27,26 @@ using std::string;
 namespace
 {
 
-  class LsofBase
+  class Lsof
   {
-    virtual bool matches(const string &filename) const = 0;
+    Glib::RefPtr<Glib::Regex> re;
+
+    bool matches(const string &filename) const
+    {
+      return this->re->match(filename);
+    }
 
   public:
 
-    virtual ~LsofBase()
-    { }
+    Lsof(const string &pattern, bool caseless)
+    {
+      Glib::RegexCompileFlags flags = static_cast<Glib::RegexCompileFlags>(0);
+
+      if (caseless)
+	flags |= Glib::REGEX_CASELESS;
+
+      this->re = Glib::Regex::create(pattern, flags);
+    }
 
 
     template<typename OutputIterator>
@@ -57,126 +70,6 @@ namespace
   };
 
 
-#ifdef FOOBAR
-
-  class Lsof
-    : public LsofBase
-  {
-    string pattern;
-    bool caseless;
-
-    virtual bool matches(const string &filename) const
-    {
-      if (this->caseless) {
-	char *cp, *cf;
-	cp = g_utf8_strdown(this->pattern.c_str(), -1);
-	cf = g_utf8_strdown(filename.c_str(), -1);
-	string p(cp), f(cf);
-	g_free(cp);
-	g_free(cf);
-	return f.find(p) != string::npos;
-      }
-
-      return filename.find(this->pattern) != string::npos;
-    }
-
-  public:
-
-    Lsof(const string &pattern, bool caseless)
-      : pattern(pattern), caseless(caseless)
-    { }
-  };
-
-#elif 0
-
-  class Lsof
-    : public LsofBase
-  {
-    pcrecpp::RE re;
-
-    virtual bool matches(const string &filename) const
-    {
-      return this->re.PartialMatch(filename);
-    }
-
-  public:
-
-    Lsof(const string &pattern, bool caseless)
-      : re(pattern, pcrecpp::RE_Options().set_caseless(caseless).set_utf8(true))
-    { }
-  };
-
-#else
-  class Lsof
-    : public LsofBase
-  {
-    string pattern;
-    bool caseless;
-
-
-    static string escape(const string &s)
-    {
-      char *escaped = g_strescape(s.c_str(), "");
-      string ret(escaped);
-      g_free(escaped);
-
-      return ret;
-    }
-
-
-    virtual bool matches(const string &filename) const
-    {
-      string argv1, argv2;
-
-      argv1 = escape(this->pattern);
-      argv2 = escape(filename);
-
-      const char *argv[7];
-
-      argv[0] = "python";
-      argv[1] = "-c";
-      argv[2] = "import sys, re; "
-	"sys.exit(re.search(sys.argv[1], sys.argv[2], "
-	"(bool(sys.argv[3]) and re.I or 0)) is None)";
-      argv[3] = argv1.c_str();
-      argv[4] = argv2.c_str();
-      argv[5] = this->caseless ? "1" : "0";
-      argv[6] = NULL;
-
-      int status;
-      GError *error = NULL;
-
-      if (g_spawn_sync(NULL, // cwd
-		       const_cast<gchar**>(argv), NULL, // argv and env
-		       static_cast<GSpawnFlags>(G_SPAWN_SEARCH_PATH
-					       | G_SPAWN_STDOUT_TO_DEV_NULL
-					       | G_SPAWN_STDERR_TO_DEV_NULL), // flags
-		       NULL, NULL, // child_setup and user_data
-		       NULL, NULL, // stdin, stdout
-		       &status,
-		       &error)) {
-	if (!error and WIFEXITED(status))
-	  return WEXITSTATUS(status) == 0;
-      }
-
-      if (error) {
-	procman_debug("Failed to spawn python for re : %s", error->message);
-	g_error_free(error);
-      }
-
-      return false;
-    }
-
-  public:
-
-    Lsof(const string &pattern, bool caseless)
-      : pattern(pattern), caseless(caseless)
-    { }
-  };
-
-#endif
-
-
 
   // GUI Stuff
 
@@ -246,28 +139,35 @@ namespace
 
       this->clear_results();
 
-      Lsof lsof(this->pattern(), this->case_insensitive);
-      // lsof = new SimpleLsof(this->pattern(), this->case_insensitive);
       unsigned count = 0;
 
-      for (ProcInfo::Iterator it(ProcInfo::begin()); it != ProcInfo::end(); ++it) {
-	const ProcInfo &info(*it->second);
+      try {
+	Lsof lsof(this->pattern(), this->case_insensitive);
 
-	MatchSet matches;
-	lsof.search(info, std::inserter(matches, matches.begin()));
-	count += matches.size();
+	for (ProcInfo::Iterator it(ProcInfo::begin()); it != ProcInfo::end(); ++it) {
+	  const ProcInfo &info(*it->second);
 
-	for (iterator it(matches.begin()), end(matches.end()); it != end; ++it) {
-	  GtkTreeIter file;
-	  gtk_list_store_append(this->model, &file);
-	  gtk_list_store_set(this->model, &file,
-			     PROCMAN_LSOF_COL_PIXBUF, info.pixbuf,
-			     PROCMAN_LSOF_COL_PROCESS, info.name,
-			     PROCMAN_LSOF_COL_PID, info.pid,
-			     PROCMAN_LSOF_COL_FILENAME, it->c_str(),
-			     -1);
+	  MatchSet matches;
+	  lsof.search(info, std::inserter(matches, matches.begin()));
+	  count += matches.size();
+
+	  for (iterator it(matches.begin()), end(matches.end()); it != end; ++it) {
+	    GtkTreeIter file;
+	    gtk_list_store_append(this->model, &file);
+	    gtk_list_store_set(this->model, &file,
+			       PROCMAN_LSOF_COL_PIXBUF, info.pixbuf->gobj(),
+			       PROCMAN_LSOF_COL_PROCESS, info.name,
+			       PROCMAN_LSOF_COL_PID, info.pid,
+			       PROCMAN_LSOF_COL_FILENAME, it->c_str(),
+			       -1);
+	  }
 	}
       }
+      catch (Glib::RegexError& error) {
+	procman_debug("Regex error with pattern '%s' : %s",
+		      this->pattern().c_str(),
+		      error.what().c_str());
+      }
 
       this->update_count(count);
     }
