@@ -51,7 +51,7 @@ namespace
 
     void set(const glibtop_map_entry &last_map)
     {
-      this->format = (last_map.end <= G_MAXUINT32) ? "%08llx" : "%016llx";
+      this->format = (last_map.end <= G_MAXUINT32) ? "%08" G_GINT64_MODIFIER "x" : "%016" G_GINT64_MODIFIER "x";
     }
 
     string operator()(guint64 v) const
@@ -267,7 +267,7 @@ namespace
       guint16 dev = dev64 & 0xffff;
 
       if (dev != dev64)
-	g_warning("weird device %llx", dev64);
+	g_warning("weird device %" G_GINT64_MODIFIER "x", dev64);
 
       Map::iterator it(this->devices.find(dev));
 
@@ -476,14 +476,26 @@ create_memmapsdata (ProcData *procdata)
 
 	const gchar * const titles[] = {
 		N_("Filename"),
+		// xgettext: virtual memory start
 		N_("VM Start"),
+		// xgettext: virtual memory end
 		N_("VM End"),
+		// xgettext: virtual memory syze
 		N_("VM Size"),
 		N_("Flags"),
+		// xgettext: virtual memory offset
 		N_("VM Offset"),
+		// xgettext: memory that has not been modified since
+		// it has been allocated
 		N_("Private clean"),
+		// xgettext: memory that has been modified since it
+		// has been allocated
 		N_("Private dirty"),
+		// xgettext: shared memory that has not been modified
+		// since it has been allocated
 		N_("Shared clean"),
+		// xgettext: shared memory that has been modified
+		// since it has been allocated
 		N_("Shared dirty"),
 		N_("Device"),
 		N_("Inode")
